ConnectedElementCreation class final

One element creation request materialized with its incoming connector in a single canonical transaction.

Constructors

ConnectedElementCreation({required ConnectorEndpoint source, required ElementCreation element, String? targetPortId, String? connectorId, String connectorType = 'connector', ConnectorRoute route = ConnectorRoute.straight, int connectorZIndex = -1})
const

Properties

connectorId → String?
final
connectorType → String
final
connectorZIndex → int
final
element → ElementCreation
final
hashCode → int
The hash code for this object.
no setterinherited
route → ConnectorRoute
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → ConnectorEndpoint
final
targetPortId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited