DiagramConnectorControlHandle class final

Dragging the control point at controlPointIndex of the connector elementId, from the connector's controlPoints at the start of the gesture.

Inheritance

Constructors

DiagramConnectorControlHandle(String elementId, int controlPointIndex, List<DiagramPoint> controlPoints)

Properties

autoPan → bool
Only movement and resizing pan by default; custom gestures opt in.
no setterinherited
autoWidthOnClick → bool
no setterinherited
controlPointIndex → int
final
controlPoints → List<DiagramPoint>
final
cornerX → double?
no setterinherited
cornerY → double?
no setterinherited
editAfterCreation → bool
no setterinherited
elementId → String
final
gesture → DiagramToolGesture?
no setterinherited
gestureStart → DiagramEditorState?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
historyLabel → String
no setterinherited
kind → DiagramDragKind
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapeType → String?
no setterinherited
worldPosition → DiagramPoint?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited