DiagramContentOperation class final

One content paint step for an element: the whole element, or the phase of a shape that is split around mounted widgets.

For DiagramContentPhase.layers, layers are the layers to paint. excludedWidgetSlotIds names widget slots whose fallback content is skipped because a widget is mounted there.

Constructors

DiagramContentOperation(ResolvedElement element, {DiagramContentPhase phase = DiagramContentPhase.whole, Iterable<ResolvedShapeLayer> layers = const [], Iterable<String> excludedWidgetSlotIds = const []})

Properties

cacheKey → Object
latefinal
element → ResolvedElement
final
excludedWidgetSlotIds → Set<String>
final
hashCode → int
The hash code for this object.
no setterinherited
layers → List<ResolvedShapeLayer>
final
phase → DiagramContentPhase
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited