One geometry owner for both handle painting and pointer hit testing.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
resolve(
ResolvedElement element, {required double zoom}) → List< DiagramControlHandle> -
resolveLabel(
ResolvedConnector connector, ResolvedConnectorLabel label) → List< DiagramControlHandle> -
resolveSelection(
Iterable< ResolvedElement> elements, {required double zoom}) → List<DiagramControlHandle> -
selectionBoundsFor(
ResolvedElement element) → DiagramRect