motionFor method

Map<String, Motion> motionFor(
  1. ResolvedScene scene
)

The Motion the commit shown by scene requested for each element it moved, by id; empty when that commit requested none. A canvas animates those elements from the geometry it last showed.

Implementation

Map<String, Motion> motionFor(ResolvedScene scene) {
  final motion = _controller.diagram._motion;
  if (motion == null ||
      motion.documentId != scene.documentId ||
      !motion.revisions.contains(scene.revision)) {
    return const {};
  }
  return motion.elements;
}