DiagramCreateFreehandHandle class final

Drawing a new freehand stroke with the id elementId, collecting its samples.

Inheritance

Constructors

DiagramCreateFreehandHandle(String elementId, DiagramFreehandSamples samples, {required DiagramPoint origin, String? parentId})

Properties

autoPan → bool
Only movement and resizing pan by default; custom gestures opt in.
no setterinherited
autoWidthOnClick → bool
no setterinherited
controlPointIndex → int?
no setterinherited
cornerX → double?
no setterinherited
cornerY → double?
no setterinherited
editAfterCreation → bool
no setterinherited
elementId → String
final
gesture → DiagramToolGesture?
no setterinherited
gestureStart → DiagramEditorState?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasPreview ↔ bool
getter/setter pairinherited
historyLabel → String
no setterinherited
kind → DiagramDragKind
no setterinherited
origin → DiagramPoint
finalinherited
parentId → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samples → DiagramFreehandSamples
final
shapeType → String?
no setterinherited
worldPosition → DiagramPoint?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited