DiagramCreateLineHandle class final

Drawing a new connector of connectorType with the id elementId, from source.

When requireBoundTarget is set, the connector is only committed if it ends on a bound target.

Inheritance

Constructors

DiagramCreateLineHandle(String elementId, {required DiagramPoint origin, String? parentId, required ConnectorEndpoint source, String connectorType = 'connector', bool requireBoundTarget = false})

Properties

autoPan → bool
Only movement and resizing pan by default; custom gestures opt in.
no setterinherited
autoWidthOnClick → bool
no setterinherited
connectorType → String
final
controlPointIndex → int?
no setterinherited
cornerX → double?
no setterinherited
cornerY → double?
no setterinherited
editAfterCreation → bool
no setterinherited
elementId → String
final
gesture → DiagramToolGesture?
no setterinherited
gestureStart → DiagramEditorState?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasPreview ↔ bool
getter/setter pairinherited
historyLabel → String
no setterinherited
kind → DiagramDragKind
no setterinherited
origin → DiagramPoint
finalinherited
parentId → String?
finalinherited
requireBoundTarget → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapeType → String?
no setterinherited
source → ConnectorEndpoint
final
worldPosition → DiagramPoint?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited