shapeStyle method
The style for a new shape of type, or null for its registered default.
Implementation
ShapeStyle? shapeStyle(String type) => shapes[type] ?? shape;
The style for a new shape of type, or null for its registered default.
ShapeStyle? shapeStyle(String type) => shapes[type] ?? shape;