DiagramDragHandle class sealed

Closed gesture payloads: inactive operation fields are never stored.

Implementers

Constructors

DiagramDragHandle.connectorBend(String id)
const
factory
DiagramDragHandle.connectorControl(String id, int index, List<DiagramPoint> controlPoints)
factory
DiagramDragHandle.connectorEnd(String id)
const
factory
DiagramDragHandle.connectorStart(String id)
const
factory
DiagramDragHandle.customTool(DiagramToolGesture gesture, DiagramEditorState start)
const
factory
DiagramDragHandle.eraser()
factory
DiagramDragHandle.marquee({required DiagramPoint origin, required Set<String> baseSelection, required bool toggle})
factory
DiagramDragHandle.move({DiagramMoveClickIntent? click, bool usesTranslationPreview})
const
factory
DiagramDragHandle.pan()
const
factory
DiagramDragHandle.resize(String? id, double x, double y, {DiagramPoint? worldPosition})
const
factory
DiagramDragHandle.rotate(String id, double x, double y, {DiagramPoint? worldPosition})
const
factory
DiagramDragHandle.touchNavigation()
const
factory

Properties

autoPan → bool
Only movement and resizing pan by default; custom gestures opt in.
no setter
autoWidthOnClick → bool
no setter
controlPointIndex → int?
no setter
cornerX → double?
no setter
cornerY → double?
no setter
editAfterCreation → bool
no setter
elementId → String?
no setter
gesture → DiagramToolGesture?
no setter
gestureStart → DiagramEditorState?
no setter
hashCode → int
The hash code for this object.
no setterinherited
historyLabel → String
no setter
kind → DiagramDragKind
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapeType → String?
no setter
worldPosition → DiagramPoint?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited