DiagramEditConnectorLabelOnClick class final

A click on the connector connectorId that edits its label if the pointer stays near screenOrigin, in screen coordinates.

Constructors

DiagramEditConnectorLabelOnClick(String connectorId, DiagramPoint screenOrigin)
const

Properties

connectorId → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenOrigin → DiagramPoint
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited