DiagramEditTextOnClick class final
Starts editing the text of the element elementId at world, where doubleTap records whether the click was a double tap.
- Inheritance
-
- Object
- DiagramMoveClickIntent
- DiagramEditTextOnClick
Constructors
- DiagramEditTextOnClick(String elementId, DiagramPoint world, {required bool doubleTap})
-
const
Properties
- doubleTap → bool
-
final
- elementId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- world → DiagramPoint
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited