Optional image resources supplied by a platform output adapter.
- Implemented types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
exportPng(
DiagramSnapshot snapshot, PngOptions options) → Future< PngSnapshot> -
Renders
snapshotas PNG, cropped to PngOptions.bounds.inherited -
exportPngWithImages(
DiagramSnapshot snapshot, PngOptions options, Object imageProvider(DiagramImageSource)) → Future< PngSnapshot> -
exportSvg(
DiagramSnapshot snapshot, SvgOptions options) → Future< SvgSnapshot> -
Renders
snapshotas SVG, cropped to SvgOptions.bounds.inherited -
exportSvgWithImages(
DiagramSnapshot snapshot, SvgOptions options, Object imageProvider(DiagramImageSource)) → Future< SvgSnapshot> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited