DiagramInteractionController class final

Semantic interaction ownership shared by every surface of a controller. Notifies when the canvas world changes, such as entering text editing.

Available extensions

Properties

activePointerId → int?
no setter
dragHandle → DiagramDragHandle?
no setter
editingElementId → String?
no setter
editingStoryId → String?
no setter
editingTarget → ResolvedDiagramTextTarget?
no setter
focusedGroupId → String?
no setter
groupFocusPath → List<String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
labelClickIntent → DiagramEditConnectorLabelOnClick?
no setter
lease ↔ DiagramInteractionLease?
getter/setter pair
moveClickIntent → DiagramMoveClickIntent?
no setter
moveGuides ↔ List<DiagramMoveGuide>
Guides a move adjuster shows for the current move preview.
getter/setter pair
movePreview ↔ DiagramMovePreview?
getter/setter pair
reparentTargetId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
store → DiagramController
final
transformBaseline → DiagramTransformBaseline?
no setter
world ↔ DiagramEditorInteractionWorld
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
canMoveFromContent(ResolvedElement element) → bool
discardMoveClickIntent() → void
dispose() → void
Discards any resources used by the object.
inherited
enterGroup(String groupId) → void
exitFocusedGroup() → void
isWithinGroup(ResolvedElement element, String groupId) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
previewMove(DiagramPoint world, {required DiagramPoint snapPoint(DiagramPoint), bool shouldReparent = false, DiagramMoveAdjuster? adjuster, required double zoom, required DiagramRect viewportBounds}) → void

Available on DiagramInteractionController, provided by the DiagramInteractionMove extension

previewResize(DiagramPoint world, {required DiagramPoint snapPoint(DiagramPoint), bool preserveAspectRatio = false, bool fromCenter = false}) → void

Available on DiagramInteractionController, provided by the DiagramInteractionResize extension

previewRotate(DiagramPoint world, {bool snapAngle = false}) → void

Available on DiagramInteractionController, provided by the DiagramInteractionRotate extension

removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
replaceGestureHandle(DiagramDragHandle handle) → void
Changing a click into a drag keeps the original transform baseline.
reset() → void
returnToCanvasWorld({bool clearGroupFocus = false}) → void
returnToDefaultTool() → void
selectionTargetFor(ResolvedElement hit, {bool deep = false}) → ResolvedElement
setCanvasWorld(List<String> groupFocusPath) → void
setGestureWorld(int pointerId, DiagramDragHandle handle, {DiagramEditConnectorLabelOnClick? labelClick}) → void
setTransformWorld(DiagramToolPointer pointer, DiagramDragHandle handle, Set<String> selectedIds, {DiagramEditConnectorLabelOnClick? labelClick}) → void
toString() → String
A string representation of this object.
inherited
validGroupFocusPath(List<String> path) → List<String>

Operators

operator ==(Object other) → bool
The equality operator.
inherited