withValue method
A copy with value replacing the options of its type.
Implementation
DiagramOptions withValue(Object value) => DiagramOptions._(
Map.unmodifiable({...values, value.runtimeType: value}),
bounds,
fonts,
defaultFontFamily,
);
A copy with value replacing the options of its type.
DiagramOptions withValue(Object value) => DiagramOptions._(
Map.unmodifiable({...values, value.runtimeType: value}),
bounds,
fonts,
defaultFontFamily,
);