DiagramParticipantState class final
Immutable local interaction choices, independent of committed content. Each controller owns one such value. This value alone does not establish independent participant ownership.
Constructors
- DiagramParticipantState({required DiagramSelection selection, required DiagramCameraState camera, DiagramTool activeTool = DiagramTools.select, ConnectorRoute activeConnectorRoute = ConnectorRoute.straight, DiagramCreationStyles creationStyles = const DiagramCreationStyles()})
-
const
Properties
- activeConnectorRoute → ConnectorRoute
-
final
- activeTool → DiagramTool
-
final
- camera → DiagramCameraState
-
final
- creationStyles → DiagramCreationStyles
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selection → DiagramSelection
-
final
Methods
-
copyWith(
{DiagramSelection? selection, DiagramCameraState? camera, DiagramTool? activeTool, ConnectorRoute? activeConnectorRoute, DiagramCreationStyles? creationStyles}) → DiagramParticipantState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited