DiagramRotateHandle class final

Rotating the element elementId from a handle.

cornerX and cornerY give the position of the handle, as for DiagramResizeHandle.

Inheritance

Constructors

DiagramRotateHandle(String elementId, double cornerX, double cornerY, {DiagramPoint? worldPosition})
const

Properties

autoPan → bool
Only movement and resizing pan by default; custom gestures opt in.
no setterinherited
autoWidthOnClick → bool
no setterinherited
controlPointIndex → int?
no setterinherited
cornerX → double
final
cornerY → double
final
editAfterCreation → bool
no setterinherited
elementId → String
final
gesture → DiagramToolGesture?
no setterinherited
gestureStart → DiagramEditorState?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
historyLabel → String
no setterinherited
kind → DiagramDragKind
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapeType → String?
no setterinherited
worldPosition → DiagramPoint?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited