DiagramSelectOnClick class final

Selects the element elementId, or toggles it in the selection when toggle is set.

Inheritance

Constructors

DiagramSelectOnClick(String elementId, {required bool toggle})
const

Properties

elementId → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toggle → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited