DiagramStep class sealed

One change a DiagramTransaction makes. There are four: insert elements, remove elements, replace one element and replace the whole document. Moves, resizes, rotations and text edits are replacements.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(DiagramDocument document) → DiagramDocument
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited