DiagramTextBoundaryMap class final
UTF-16 positions at extended grapheme boundaries in canonical story text. Boundaries span inline runs and are independent of visual line wrapping.
Constructors
- DiagramTextBoundaryMap(String text)
Properties
Methods
-
after(
int offset) → int -
before(
int offset) → int -
isBoundary(
int offset) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited