DiagramTextEditingInteractionWorld class final

The world in which the story storyId of the element elementId is being edited.

activationTap is the tap that started the edit, when there was one.

Inheritance

Constructors

DiagramTextEditingInteractionWorld(String elementId, String storyId, {({int count, Duration timeStamp, DiagramPoint world})? activationTap, List<String> groupFocusPath = const []})
const

Properties

activationTap → ({int count, Duration timeStamp, DiagramPoint world})?
final
elementId → String
final
groupFocusPath → List<String>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storyId → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited