resolvedFrames property
Resolved frames captured for resize, including automatic text growth.
Implementation
final Map<String, FramedElement> resolvedFrames;
Resolved frames captured for resize, including automatic text growth.
final Map<String, FramedElement> resolvedFrames;