InsertElementsStep class final

Inserts new elements, in order.

Inheritance

Constructors

InsertElementsStep(List<DiagramElement> elements)

Properties

elements → List<DiagramElement>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(DiagramDocument document) → DiagramDocument
inherited
applyTo(DiagramDocumentBatch batch) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited