ReplaceDocumentStep class final

Replaces the whole expected document with replacement.

Inheritance

Constructors

ReplaceDocumentStep({required DiagramDocument expected, required DiagramDocument replacement})
const

Properties

expected → DiagramDocument
final
hashCode → int
The hash code for this object.
no setterinherited
replacement → DiagramDocument
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(DiagramDocument document) → DiagramDocument
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited