ReplaceElementStep class final

Replaces element before with after, which keeps its identity.

Inheritance

Constructors

ReplaceElementStep({required DiagramElement before, required DiagramElement after})
const

Properties

after → DiagramElement
final
before → DiagramElement
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(DiagramDocument document) → DiagramDocument
inherited
applyTo(DiagramDocumentBatch batch) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited