DiagramConnectorRouteFallback class final
Degraded but valid geometry, published with a reason the UI can surface.
- Inheritance
-
- Object
- DiagramConnectorRouteResult
- DiagramConnectorRouteFallback
Constructors
- DiagramConnectorRouteFallback(DiagramConnectorRouteGeometry geometry, DiagramConnectorRouteDiagnostic diagnostic)
-
const
Properties
- diagnostic → DiagramConnectorRouteDiagnostic
-
final
- geometry → DiagramConnectorRouteGeometry
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited