DiagramOutputSnapshot<Scene> class abstract interface

Immutable document and its corresponding resolved scene, owned by the engine.

Implementers

Properties

document → DiagramDocument
The document that was captured.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scene → Scene
The resolved scene of document.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited