DiagramShapeTool class final
Creates any registered shape; no built-in shape identifiers are special.
- Inheritance
-
- Object
- DiagramToolBehavior
- DiagramShapeTool
Constructors
- DiagramShapeTool({required String shapeType, bool editAfterCreation = false, bool autoWidthOnClick = false})
-
const
Properties
- autoWidthOnClick → bool
-
final
- creationShapeType → String
-
Registered shape whose appearance can be configured before creation.
no setteroverride
- editAfterCreation → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shapeType → String
-
final
Methods
-
hover(
DiagramToolContext context, DiagramToolPointer pointer) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pointerDown(
DiagramToolContext context, DiagramToolPointer pointer) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
ShapeRegistry shapes) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited