DiagramTextCodec class abstract interface

Versioned persistence of the paragraph and run attributes one text definition owns, such as rich text's lists and marks. Attributes are dispatched to the codec whose type they declare.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setter
version → int
no setter

Methods

decodeParagraph(Map<String, Object?> data, int version) → TextParagraphAttributes
decodeRun(Map<String, Object?> data, int version) → TextRunAttributes
encodeParagraph(TextParagraphAttributes attributes) → Map<String, Object?>
encodeRun(TextRunAttributes attributes) → Map<String, Object?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited