present method
The paragraph as laid out, for example with a heading's size applied. Text, identity and slot must be preserved.
Implementation
TextParagraph present(TextParagraph paragraph, double defaultFontSize) =>
paragraph;
The paragraph as laid out, for example with a heading's size applied. Text, identity and slot must be preserved.
TextParagraph present(TextParagraph paragraph, double defaultFontSize) =>
paragraph;