DiagramTextKeyContext class final
The text a key chord applies to.
Constructors
- DiagramTextKeyContext({required TextStory story, required int start, required int end, required bool editing, required TextRun typingStyle, double defaultFontSize = diagramDefaultFontSize, DiagramTextFontSizeRange fontSizeRange = const DiagramTextFontSizeRange()})
-
const
Properties
- defaultFontSize → double
-
final
- editing → bool
-
False when the story is selected as an object rather than edited.
final
- end → int
-
Story offsets of the edited range; the whole story for an object.
final
- fontSizeRange → DiagramTextFontSizeRange
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCaret → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int
-
Story offsets of the edited range; the whole story for an object.
final
- story → TextStory
-
final
- typingStyle → TextRun
-
The style of the next typed text at a caret.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited