DiagramTextPresentation class final

A single line of text.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxLines → int
The lines shown before the text scrolls.
final
minLines → int?
The lines shown while empty; null for maxLines when single-line.
final
multiline → bool
Whether the text spans several lines: Enter starts a new line and the value is committed when editing ends.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited