DiagramToolBehavior class abstract

Open behavior interface used equally by standard and host-defined tools.

Implementers

Constructors

DiagramToolBehavior()
const

Properties

creationShapeType → String?
Registered shape whose appearance can be configured before creation.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

hover(DiagramToolContext context, DiagramToolPointer pointer) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointerDown(DiagramToolContext context, DiagramToolPointer pointer) → void
toString() → String
A string representation of this object.
inherited
validate(ShapeRegistry shapes) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited