DiagramVerbInvocation class final

One verb call as a value: what a key binding, a toolbar item or a gesture preview performs.

Constructors

DiagramVerbInvocation(Iterable<String> ids, String verb, [Map<String, Object?> args = const {}])

Properties

args → Map<String, Object?>
final
hashCode → int
The hash code for this object.
no setterinherited
ids → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verb → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited