GraphLayoutRequest class final

Immutable, renderer-independent input to a layout algorithm.

Constructors

GraphLayoutRequest({required Iterable<GraphLayoutNode> nodes, required Iterable<GraphLayoutEdge> edges})

Properties

edges → List<GraphLayoutEdge>
final
hashCode → int
The hash code for this object.
no setterinherited
nodes → List<GraphLayoutNode>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited