ResolvedDiagramTextTarget class final
Story and geometry from the same resolved revision, with edit admission.
Properties
- canonical → DiagramTextTarget
-
final
- defaultFontSize → double
-
final
- editable → bool
-
final
- fontSizeRange → DiagramTextFontSizeRange
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- objectSelection → DiagramSelection
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → ResolvedTextStory?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
textFor(
TextParagraph paragraph) → DiagramTextDefinition -
The text filling the slot of
paragraph, which decides what the paragraph admits and how it edits. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
resolve(
ResolvedElement? element, String storyId) → ResolvedDiagramTextTarget?