container property
ShapeContainer?
get
container
The container policy of a shape that owns children, else null.
Implementation
ShapeContainer? get container => null;
The container policy of a shape that owns children, else null.
ShapeContainer? get container => null;