container property
The container policy of a shape that owns children, else null.
Implementation
@override
ShapeContainer? get container => definition.container;
The container policy of a shape that owns children, else null.
@override
ShapeContainer? get container => definition.container;