defaultPorts property
Named fallback ports for instance-editable connections. These are replaced as a whole when the instance supplies its own ports, unlike fixedPorts.
Implementation
final List<PortDefinition> defaultPorts;
Named fallback ports for instance-editable connections. These are replaced as a whole when the instance supplies its own ports, unlike fixedPorts.
final List<PortDefinition> defaultPorts;