createContent method

TextStoryContent? createContent(
  1. String elementId
)

Creates authored content once when a new owner is created. A visual-only provider may leave the region without a story payload.

Implementation

TextStoryContent? createContent(String elementId) => null;