verbs property

List<DiagramVerb> get verbs

The verbs of this content part, such as a table's insertRow. A shape binds them to this part; they are qualified by slotId only when the shape has several parts offering the same verb.

Implementation

List<DiagramVerb> get verbs => const [];