ShapeContentLayoutProvider class abstract interface

A portable provider for a registered structured content region.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setter

Methods

canDeleteSelection(DiagramController store, ContentSelection selection) → bool
createSession(DiagramTextLayoutEngine textLayout) → ShapeContentLayoutSession
deleteSelection(DiagramController store, ContentSelection selection) → EditResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited