ShapeImage class final
The image the shape stores in its ImageValueField valueKey, fitted to this region, or a placeholder until one is chosen.
Constructors
- ShapeImage([String valueKey = 'image'])
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minimumSize → DiagramSize
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valueKey → String
-
final
Methods
-
minimumSizeFor(
FramedElement shape, Map< String, double> textHeights) → DiagramSize -
inherited
-
named(
String name) → ShapePart -
Reuses this part with namespaced text slots and explicitly named surfaces.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited