ShapeLibrary class final
A reusable collection. Selecting libraries never silently replaces a type.
Constructors
-
ShapeLibrary({required String id, required String name, required Iterable<
ShapeDefinition> shapes})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
select(
Iterable< String> types, {required String id, required String name}) → ShapeLibrary - Reuse selected definitions in another library without copying their implementation.
-
shape(
String type) → ShapeDefinition -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited