ShapeShadowDefinition class final
Paint-only shadow derived from a shape production.
Constructors
- ShapeShadowDefinition({required DiagramColor color, DiagramPoint offset = const DiagramPoint(0, 2), double blurRadius = 6})
-
const
Properties
- blurRadius → double
-
final
- color → DiagramColor
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- offset → DiagramPoint
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visualOutset → double
-
Finite Gaussian support used by scene bounds and SVG filter regions.
blurRadius is sigma, matching the canvas mask filter.
no setter
Methods
-
filterBounds(
DiagramRect outlineBounds) → DiagramRect -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visualBounds(
DiagramRect outlineBounds) → DiagramRect
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited