editable property
False keeps people from editing this slot on the canvas; commands and verbs still set its text.
Implementation
final bool editable;
False keeps people from editing this slot on the canvas; commands and verbs still set its text.
final bool editable;