DiagramCreateShapeHandle class final
Drawing a new shape of shapeType with the id elementId.
editAfterCreation starts text editing once the shape is created. autoWidthOnClick sizes the shape's text automatically when the gesture is a click rather than a drag.
- Inheritance
-
- Object
- DiagramDragHandle
- DiagramCreationHandle
- DiagramCreateShapeHandle
Constructors
- DiagramCreateShapeHandle(String elementId, String shapeType, {required DiagramPoint origin, String? parentId, bool editAfterCreation = false, bool autoWidthOnClick = false})
Properties
- autoPan → bool
-
Only movement and resizing pan by default; custom gestures opt in.
no setterinherited
- autoWidthOnClick → bool
-
final
- controlPointIndex → int?
-
no setterinherited
- cornerX → double?
-
no setterinherited
- cornerY → double?
-
no setterinherited
- editAfterCreation → bool
-
final
- elementId → String
-
final
- gesture → DiagramToolGesture?
-
no setterinherited
- gestureStart → DiagramEditorState?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPreview ↔ bool
-
getter/setter pairinherited
- historyLabel → String
-
no setterinherited
- kind → DiagramDragKind
-
no setterinherited
- origin → DiagramPoint
-
finalinherited
- parentId → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shapeType → String
-
final
- worldPosition → DiagramPoint?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited