DiagramCreationDefaults class final
Styles a host (such as a themed canvas) gives new content. Explicit participant choices in DiagramCreationStyles take precedence.
Constructors
-
DiagramCreationDefaults({ShapeStyle? shape, Map<
String, ShapeStyle> shapes = const {}, ConnectorStyle? connector}) -
const
Properties
- connector → ConnectorStyle?
-
Style for new connectors.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → ShapeStyle?
-
Style for new shapes whose type has no entry in shapes.
final
-
shapes
→ Map<
String, ShapeStyle> -
Styles for new shapes of a type, keyed by shape type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shapeStyle(
String type) → ShapeStyle? -
The style for a new shape of
type, or null for its registered default. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited