DiagramEditorInteractionWorld class sealed
The complete, closed set of editor focus worlds. Keeping this separate from Flutter focus nodes prevents a mounted editor from becoming a dead, non-interactive surface when focus changes.
Properties
-
groupFocusPath
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited