DiagramMoveHandle class final
Moving the selection.
A press that never becomes a drag acts as the click intent, if any. usesTranslationPreview is set when the preview can be a pure translation of the captured elements.
- Inheritance
-
- Object
- DiagramDragHandle
- DiagramMoveHandle
Constructors
- DiagramMoveHandle({DiagramMoveClickIntent? click, bool usesTranslationPreview = false})
-
const
Properties
- autoPan → bool
-
Only movement and resizing pan by default; custom gestures opt in.
no setterinherited
- autoWidthOnClick → bool
-
no setterinherited
- click → DiagramMoveClickIntent?
-
final
- controlPointIndex → int?
-
no setterinherited
- cornerX → double?
-
no setterinherited
- cornerY → double?
-
no setterinherited
- editAfterCreation → bool
-
no setterinherited
- elementId → String?
-
no setterinherited
- gesture → DiagramToolGesture?
-
no setterinherited
- gestureStart → DiagramEditorState?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- historyLabel → String
-
no setterinherited
- kind → DiagramDragKind
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shapeType → String?
-
no setterinherited
- usesTranslationPreview → bool
-
final
- worldPosition → DiagramPoint?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited