installDefaultTextLayout method
Installs the first platform shaper only when no explicit backend was supplied. The owning diagram must refresh its publication immediately afterwards.
Implementation
bool installDefaultTextLayout(DiagramTextLayoutEngine backend) {
if (!_usesDefaultTextLayout) return false;
_usesDefaultTextLayout = false;
_textLayout = backend;
_textLayoutRevision = null;
return true;
}