DiagramSpatialIndex class final
A grid index of resolved elements by their bounds.
query returns the elements whose bounds intersect an area, in paint order, without scanning every element.
Constructors
-
DiagramSpatialIndex(Iterable<
ResolvedElement> elements) -
DiagramSpatialIndex.incremental(DiagramSpatialIndex previous, List<
ResolvedElement> elements, {Iterable<int> ? changedIndexes, Iterable<String> ? changedIds}) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
DiagramRect worldBounds) → Iterable< ResolvedElement> -
Elements whose bounds intersect
worldBounds, in paint order. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited