DiagramTransformBaseline class final
Immutable input to every preview in one admitted transform sequence.
Constructors
-
DiagramTransformBaseline({required DiagramPoint origin, required DiagramTransformPlan plan, required Set<
String> selectedIds, required List<ConnectorElement> incidentConnections, required DiagramRect? selectionBounds})
Properties
-
elements
→ Map<
String, DiagramElement> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
incidentConnections
→ List<
ConnectorElement> -
final
- origin → DiagramPoint
-
final
- plan → DiagramTransformPlan
-
The captured elements and the steps every preview derives from.
final
-
resolvedShapes
→ Map<
String, FramedElement> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedIds
→ Set<
String> -
final
- selectionBounds → DiagramRect?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited