RemoveElementsStep class final
Removes the requested elements with what depends on them: owned contents and connectors that would keep a binding to a removed element.
- Inheritance
-
- Object
- DiagramStep
- RemoveElementsStep
Constructors
-
RemoveElementsStep(Set<
String> elementIds)
Properties
-
elementIds
→ Set<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
DiagramDocument document) → DiagramDocument -
inherited
-
applyTo(
DiagramDocumentBatch batch) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited