ShapeRegionInteraction class final
One step of a pointer gesture on an interactive region of a shape.
A ShapeRegionInteractionHandler receives it for the region's interactionId, first with ShapeRegionInteractionPhase.start, then for each later phase if the handler accepted the gesture.
Constructors
- ShapeRegionInteraction({required String elementId, required String regionId, required String interactionId, required ShapeRegionInteractionPhase phase, required DiagramPoint worldPoint, required DiagramPoint localPoint})
-
const
Properties
- elementId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interactionId → String
-
final
- localPoint → DiagramPoint
-
final
- phase → ShapeRegionInteractionPhase
-
final
- regionId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- worldPoint → DiagramPoint
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited