Anything that contributes properties, resolved for what is being edited.
Installed extensions, route and content providers contribute simply by implementing this interface, and the text being inspected contributes its text definitions' properties; hosts and editors pass further sources to DiagramProperties.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
propertiesFor(
DiagramPropertyScope scope) → Iterable< DiagramProperty< Object?, Object?> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited