ResolvedElement class abstract
An element resolved to geometry: its id, zIndex, bounds and hit testing. Shapes, text elements and connectors have resolved forms.
- Implementers
Constructors
- ResolvedElement({required String id, bool isLocked = false, required int zIndex, required DiagramRect bounds})
-
const
Properties
- bounds → DiagramRect
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isLocked → bool
-
final
- opacity → double
-
Complete-element opacity from canonical appearance.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zIndex → int
-
final
Methods
-
hitTest(
DiagramPoint worldPoint, {double tolerance = 5}) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited