ResolvedShapeContent class abstract
Immutable extension geometry lowered to the renderer's shared productions.
Constructors
- ResolvedShapeContent()
-
const
Properties
- bounds → DiagramRect
-
no setter
- contentId → String
-
no setter
- contentType → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
layers
→ Iterable<
ResolvedShapeLayer> -
no setter
- requiredSize → DiagramSize
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slotId → String
-
no setter
-
textRegions
→ Iterable<
DiagramTextRegionLayout> -
no setter
Methods
-
allowsMultiClickTextSelection(
DiagramPoint local, ResolvedTextStory text) → bool -
mapSelection(
ContentSelection selection) → DiagramSelection -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
selectionForTextBlock(
String elementId, String blockId) → DiagramSelection? -
textRegionForBlock(
String blockId) → ResolvedContentTextRegion? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited