Immutable nested authored content supplied by a model extension.
Canonical identities include hidden content. The editing projection may combine slots, but replacement must preserve each constituent's ownership.
Properties
-
canonicalIds
→ Iterable<
String> -
no setter
-
canonicalParagraphs
→ Iterable<
TextParagraph> -
no setter
- contentType → String
-
no setter
-
editingParagraphs
→ Iterable<
TextParagraph> -
no setter
-
editingSlotIds
→ Iterable<
String> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slotId → String
-
no setter
Methods
-
clone(
String nextId(String kind)) → TextStoryContent -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replaceParagraphs(
List< TextParagraph> paragraphs, {TextStoryContent? previous}) → TextStoryContent -
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited